# flake8: noqa
##############################################################################
#
#    Copyright © 2019 XCG Consulting <http://odoo.consulting>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################
from datetime import date

from dateutil.relativedelta import relativedelta

from odoo import _, _lt

from odoo.addons.icuformat import icu_format


class ArgumentException(Exception):
    def __init__(self):
        super().__init__(_lt("The second date must be after the first one"))


def humanize_duration(lang: str, date1: date, date2: date) -> str:
    """Provide an easily human representation of the duration between two days.
    The difference is expressed in terms of days, months and years."""
    if date1 > date2:
        raise ArgumentException
    relative_delta: relativedelta = relativedelta(date2, date1)
    data = {}
    msg = _(
        "{years, plural,"
        " =0 {"
        "{months, plural,"
        " =0 {"
        "{days, plural,"
        " =0 {Less than a day}"
        " one {{days} day}"
        " other {{days} days}"
        "}"
        "}"
        " one {"
        "{days, plural,"
        " =0 {{months} month}"
        " one {{months} month and {days} day}"
        " other {{months} month and {days} days}"
        "}"
        "}"
        " other {"
        "{days, plural,"
        " =0 {{months} months}"
        " one {{months} months and {days} day}"
        " other {{months} months and {days} days}"
        "}"
        "}"
        "}"
        "}"
        " one {"
        "{months, plural,"
        " =0 {"
        "{days, plural,"
        " =0 {{years} year}"
        " one {{years} year and {days} day}"
        " other {{years} year and {days} days}"
        "}"
        "}"
        " one {"
        "{days, plural,"
        " =0 {{years} year and {months} month}"
        " one {{years} year, {months} month and {days} day}"
        " other {{years} year, {months} month and {days} days}"
        "}"
        "}"
        " other {"
        "{days, plural,"
        " =0 {{years} year and {months} months}"
        " one {{years} year, {months} months and {days} day}"
        " other {{years} year, {months} months and {days} days}"
        "}"
        "}"
        "}"
        "}"
        " other {"
        "{months, plural,"
        " =0 {"
        "{days, plural,"
        " =0 {{years,number} years}"
        " one {{years,number} years and {days} day}"
        " other {{years,number} years and {days} days}"
        "}"
        "}"
        " one {"
        "{days, plural,"
        " =0 {{years,number} years and {months} month}"
        " one {{years,number} years, {months} month and {days} day}"
        " other {{years,number} years, {months} month and {days} days}"
        "}"
        "}"
        " other {"
        "{days, plural,"
        " =0 {{years,number} years and {months} months}"
        " one {{years,number} years, {months} months and {days} day}"
        " other {{years,number} years, {months} months and {days} days}"
        "}"
        "}"
        "}"
        "}"
        "}"
    )
    data["days"] = relative_delta.days
    data["months"] = relative_delta.months
    data["years"] = relative_delta.years
    return icu_format(lang, msg, data)
