###############################################################################
#
#    OpenERP, Open Source Management Solution
#    Copyright © 2019 XCG Consulting (http://www.xcg-consulting.fr/)
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
###############################################################################
from datetime import date

from odoo import tests

from .. import ArgumentException, humanize_duration


class Test(tests.TransactionCase):
    """Humanize tests"""

    def test_simple(self):
        """Simple humanize test between two dates"""
        message = humanize_duration("en", date(2017, 12, 30), date(2019, 5, 27))
        self.assertEqual("1 year, 4 months and 27 days", message)

    def test_same_day(self):
        """Humanize test with the same day"""
        today = date.today()
        message = humanize_duration("en", today, today)
        self.assertEqual("Less than a day", message)

    def test_invalid(self):
        """Test that the method raises an exception if the first date is after the
        second one."""
        with self.assertRaises(ArgumentException):
            humanize_duration("en", date(2021, 2, 2), date(2017, 12, 30))
